## Odoo Bike Shop

By The Atlanta Bikeshed
https://www.atlbikeshed.com
hello@atlbikeshed.com

### Key Features

Work Orders

Repair Queue

Customer Bicycles

### Create Work Orders

Add services and products from inventory to work orders and keep track of due dates, notes, past repair history, and more. When you're done, send an invoice straight from the work order or send the line items to the point of sale system.

### Repair Queue

Keep track of upcoming repairs using various views including list, calendar, and activity views. Sort and group repairs by book hours, price, or repair status. Keep track of delayed repairs and never forget about ordering parts or moving a bike back into the queue once they've arrived.

### Bicycles

Keep track of customer and shop owned bicycles and equipment. See prior work history at a glance, or find exactly where in the shop a customer owned bike was stored by the service advisor or previous technician. Keep track of information like battery key numbers so that customers can call you for a replacement.